@@ -214,10 +214,12 @@ model.binomial <- function(network)
       code <- paste0(code,
                      "\n\tA ~ dnorm(mean.A, prec.A)",
                      "\n\tfor(k in 1:", ntreat, ") { logit(T[k]) <- A + d[k] }",
-                     "\n\tfor(k in 2:", ntreat, ") {",
-                     "\n\t\tNNT[k] <- 1/(T[k] - T[1])",
-                     "\n\t\tRD[k] <- T[k] - T[1]",
-                     "\n\t\tRR[k] <- T[k]/T[1]",
+                     "\n\tfor(k in 1:", ntreat, ") {",
+                     "\n\t\tfor(kk in (k+1):", ntreat, ") {",
+                     "\n\t\tNNT[kk,k] <- 1/(T[kk] - T[k])",
+                     "\n\t\tRD[kk,k] <- T[kk] - T[k]",
+                     "\n\t\tRR[kk,k] <- T[kk]/T[k]",
+                     "\n\t\t}",
                      "\n\t}")
     }
     
